@@ -6,7 +6,7 @@
 # not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
-#	http://www.apache.org/licenses/LICENSE-2.0
+#   http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
@@ -659,36 +659,6 @@ describe Elasticsearch::Model::Indexing do
         expect(DummyIndexingModel.index_exists?).to be(false)
       end
     end
-
-    context 'when the index API raises an error' do
-
-      let(:client) do
-        double('client').tap do |cl|
-          expect(cl).to receive(:indices).and_raise(StandardError)
-        end
-      end
-
-      it 'returns false' do
-        expect(DummyIndexingModel.index_exists?).to be(false)
-      end
-    end
-
-    context 'when the indices.exists API raises an error' do
-
-      let(:client) do
-        double('client', indices: indices)
-      end
-
-      let(:indices) do
-        double('indices').tap do |ind|
-          expect(ind).to receive(:exists).and_raise(StandardError)
-        end
-      end
-
-      it 'returns false' do
-        expect(DummyIndexingModel.index_exists?).to be(false)
-      end
-    end
   end
 
   describe '#delete_index!' do
@@ -706,9 +676,13 @@ describe Elasticsearch::Model::Indexing do
     end
 
     context 'when the index is not found' do
+      let(:logger) { nil }
+      let(:transport) do
+        Elasticsearch::Transport::Client.new(logger: logger)
+      end
 
       let(:client) do
-        double('client', indices: indices, transport: double('transport', { logger: nil }))
+        double('client', indices: indices, transport: transport)
       end
 
       let(:indices) do
@@ -722,19 +696,17 @@ describe Elasticsearch::Model::Indexing do
       end
 
       context 'when the force option is true' do
-
         it 'deletes the index without raising an exception' do
           expect(DummyIndexingModelForRecreate.delete_index!(force: true)).to be_nil
         end
 
         context 'when the client has a logger' do
-
           let(:logger) do
             Logger.new(STDOUT).tap { |l| l.level = Logger::DEBUG }
           end
 
           let(:client) do
-            double('client', indices: indices, transport: double('transport', { logger: logger }))
+            double('client', indices: indices, transport: transport)
           end
 
           it 'deletes the index without raising an exception' do
@@ -942,7 +914,11 @@ describe Elasticsearch::Model::Indexing do
     end
 
     let(:client) do
-      double('client', indices: indices, transport: double('transport', { logger: nil }))
+      double('client', indices: indices, transport: transport)
+    end
+
+    let(:transport) do
+      Elasticsearch::Transport::Client.new(logger: nil)
     end
 
     let(:indices) do
@@ -954,9 +930,7 @@ describe Elasticsearch::Model::Indexing do
     end
 
     context 'when the force option is true' do
-
       context 'when the operation raises a NotFound exception' do
-
         before do
           expect(indices).to receive(:refresh).and_raise(NotFound)
         end
@@ -966,13 +940,16 @@ describe Elasticsearch::Model::Indexing do
         end
 
         context 'when the client has a logger' do
-
           let(:logger) do
             Logger.new(STDOUT).tap { |l| l.level = Logger::DEBUG }
           end
 
           let(:client) do
-            double('client', indices: indices, transport: double('transport', { logger: logger }))
+            double('client', indices: indices, transport: transport)
+          end
+
+          let(:transport) do
+            Elasticsearch::Transport::Client.new(logger: logger)
           end
 
           it 'does not raise an exception' do
@@ -987,7 +964,6 @@ describe Elasticsearch::Model::Indexing do
       end
 
       context 'when the operation raises another type of exception' do
-
         before do
           expect(indices).to receive(:refresh).and_raise(Exception)
         end
@@ -1001,7 +977,6 @@ describe Elasticsearch::Model::Indexing do
     end
 
     context 'when an index name is provided in the options' do
-
       before do
         expect(indices).to receive(:refresh).with(index: 'custom-foo')
       end
